\name{confint-methods}
\docType{methods}
\alias{confint-methods}
\alias{confint,ANY-method}
\alias{confint,profile.mle-method}
\alias{confint,mle-method}
\title{Methods for Function confint in Package `mle'}
\description{Generate confidence intervals}
\section{Methods}{\describe{

\item{object = "ANY"}{Generic function}

\item{object = "profile.mle"}{Generate confidence intervals based on
  likelihood profile.}

\item{object = "mle"}{First generate profile and then confidence
  intervals as above.}
}}
\keyword{methods}
\eof
\name{mle-class}
\docType{class}
\alias{mle-class}
\title{Class "mle". Result of maximum likelihood estimation.}
\description{This class encapsulates results of a generic maximum
  likelihood procedure.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("mle", ...)}, but
most often as the result of a call to \code{mle}.
}
\section{Slots}{
  \describe{
    \item{\code{call}:}{Object of class \code{"language"}. The call to \code{mle}}
    \item{\code{coef}:}{Object of class \code{"numeric"}. Estimated parameters}
    \item{\code{vcov}:}{Object of class \code{"matrix"}. Approximate
      variance-covariance matrix}
    \item{\code{min}:}{Object of class \code{"numeric"}. Minimum value
      of objective function.}
    \item{\code{details}:}{Object of class \code{"list"}. List returned
      from \code{optim} }
    \item{\code{minuslogl}:}{Object of class \code{"function"}. The
      negative loglikelihood function.}
    \item{\code{method}:}{Object of class \code{"character"}. The
      optimization method used.}
  }
}
\section{Methods}{
  \describe{
    \item{confint}{\code{signature(object = "mle")}: Confidence
      intervals from likelihood profiles.}
    \item{profile}{\code{signature(fitted = "mle")}: Likelihood profile
      generation.}
    \item{show}{\code{signature(object = "mle")}: Display object
      briefly.}
    \item{summary}{\code{signature(object = "mle")}: Generate object summary.}
  }
}
\keyword{classes}
\eof
\name{mle}
\alias{mle}
\title{Maximum likelihood estimation}
\description{
  Estimate parameters by the method of maximum likelihood.
}
\usage{
mle(minuslogl, start = formals(minuslogl), method = "BFGS", fixed = list(), ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{minuslogl}{Function to calculate negative log-likelihood}
  \item{start}{Named list. Initial values for optimizer}
  \item{method}{Optimization method to use. See \code{optim}}
  \item{fixed}{Named list. Parameter values to keep fixed during
    optimization}
  \item{\dots}{Further arguments to pass to \code{optim}}
}
\details{
  The \code{optim} optimizer is used to find the minimum of the negative
  log-likelihood. An approximate covariance matrix for the parameters is
  obtained by inverting the Hessian matrix at the optimum.
}
\value{
  An object of class \code{"mle"}
}
\note{Be careful to note that the argument is -log L (not -2 log L). It
  is for the user to ensure that the likelihood is correct, and that
  asymptotic likelihood inference is valid.}
\seealso{\code{\link{mle-class}}}
\examples{
x <- 0:10
y <- c(26, 17, 13, 12, 20, 5, 9, 8, 5, 4, 8)
ll <- function(ymax=15,xhalf=6)
    -sum(dpois(y,lambda=ymax/(1+x/xhalf),log=TRUE))
mle(ll)
mle(ll,fixed=list(xhalf=6))
}
\keyword{models}% at least one, from doc/KEYWORDS

\eof
\name{plot-methods}
\docType{methods}
\alias{plot-methods}
\alias{plot,ANY,ANY-method}
\alias{plot,profile.mle,missing-method}
\title{Methods for Function plot in Package `mle'}
\description{Plot objects}
\section{Methods}{\describe{

\item{x = "ANY", y = "ANY"}{Generic function}

\item{x = "profile.mle", y = "missing"}{Plot likelihood profiles for
  \code{x}}
}}
\keyword{methods}
\eof
\name{profile-methods}
\docType{methods}
\alias{profile-methods}
\alias{profile,ANY-method}
\alias{profile,mle-method}
\title{Methods for Function profile in Package `mle'}
\description{Profile likelihood}
\section{Methods}{\describe{

\item{fitted = "ANY"}{Generic function}

\item{fitted = "mle"}{Profile the likelihood in the vicinity of the optimum}
}}
\keyword{methods}
\eof
\name{profile.mle-class}
\docType{class}
\alias{profile.mle-class}
\title{Class "profile.mle"; Profiling information for "mle" object}
\description{Likelihood profiles along each parameter of likelihood function}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("profile.mle",
  ...)}, but most often by invoking \code{profile} on an "mle" object.
}
\section{Slots}{
  \describe{
    \item{\code{profile}:}{Object of class \code{"list"}. List of
      profiles, one for each requested parameter. Each profile is a data
      frame with the first column called \code{z} being the signed square
      root of the -2 log likelihood ratio, and the others being the
      parameters with names prefixed by \code{par.vals.}}
    \item{\code{summary}:}{Object of class \code{"summary.mle"}. Summary
      of object being profiled.}
  }
}
\section{Methods}{
  \describe{
    \item{confint}{\code{signature(object = "profile.mle")}: Use profile
      to generate approximate confidence intervals for parameters.}
    \item{plot}{\code{signature(x = "profile.mle", y = "missing")}: Plot
      profiles for each parameter.}
  }
}
\seealso{
  \code{\link{mle}}, \code{\link{mle-class}}, \code{\link{summary.mle-class}} 
}
%% Do we want examples for classes??
%%\examples{
%%}
\keyword{classes}
\eof
\name{show-methods}
\docType{methods}
\alias{show-methods}
\alias{show,ANY-method}
\alias{show,mle-method}
\alias{show,summary.mle-method}
\title{Methods for Function show in Package `mle'}
\description{Show objects of classes \code{mle} and \code{summary.mle}}
\section{Methods}{\describe{

\item{object = "ANY"}{Generic function}

\item{object = "mle"}{Print simple summary of \code{mle} object. Just
  the coefficients and the call.}

\item{object = "summary.mle"}{Shows call, table of coefficients and
  standard errors, and -2 log L}
}}
\keyword{methods}
\eof
\name{summary-methods}
\docType{methods}
\alias{summary-methods}
\alias{summary,ANY-method}
\alias{summary,mle-method}
\title{Methods for Function summary in Package `mle'}
\description{Summarize objects}
\section{Methods}{\describe{

\item{object = "ANY"}{Generic function}

\item{object = "mle"}{Generate a summary as an object of class
  "summary.mle", containing estimates, asymptotic SE, and value of
  -2 log L}
}}
\keyword{methods}
\eof
\name{summary.mle-class}
\docType{class}
\alias{summary.mle-class}
\title{Class "summary.mle", summary of "mle" objects}
\description{Extract of "mle" object}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("summary.mle",
  ...)}, but most often by invoking \code{summary} on an "mle" object.
They contain values meant for printing by \code{show}.
}
\section{Slots}{
  \describe{
    \item{\code{call}:}{Object of class \code{"language"} The call that
      generated the "mle" object.}
    \item{\code{coef}:}{Object of class \code{"matrix"}. Estimated
      coefficients and standard errors }
    \item{\code{m2logL}:}{Object of class \code{"numeric"}. Minus twice
      the log likelihood.}
  }
}
\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "summary.mle")}: Pretty-prints
      \code{object}  }
  }
}
\seealso{
  \code{\link{summary}}, \code{\link{mle}}, \code{\link{mle-class}} 
}
\examples{
}
\keyword{classes}
\eof
